*Recording login information
local username "********"
local password "********"

*Setting file paths
cd "\\de4.norc.org\HCCI\Home\`username'\*******\"
global logpath "*******\"
global outpath "*******\"

*Setting up log file
clear
capture log close
log using "${logpath}assessmentofspending.log", replace

***********************************
*Collecting and preparing the data*
***********************************

***Getting transplant dates***

*Setting macros for codes indicating transplant
forvalues i=1/10 {
    forvalue j=0/1 {
		forvalue k=0/1 {
			local grab = "`grab' OR proc_icd10_pcs`i'='"
			local grab = "`grab'0TY`j'0Z`k'"
			local grab = "`grab'' "
		}
	}
}

*Loading inpatient and physician services claims for transplants
clear
odbc load, exec("select yr, mnth, z_patid from HCCI_2.INP_SDDV2 is2 where substring(proc_icd9_pcs1,1,3)='556' OR substring(proc_icd9_pcs2,1,3)='556' OR  substring(proc_icd9_pcs3,1,3)='556' `grab' UNION ALL select yr, mnth, z_patid from HCCI_2.PHYS_SDDV2 ps where proc_cd='50360' OR proc_cd='50365';") dsn("Vertica") user("`username'") password("`password'")

*Cleaning transplant data
duplicates drop // Dropping duplicate observations
gen date="1-"+mnth+"-"+yr
gen tplant_date=mofd(date(date,"DMY")) // Getting month of transplant
format tplant_date %tm
keep z_patid tplant_date // Keeping only patient IDs and transplant dates
bysort z_patid (tplant_date): gen order=_n // Getting patient-wise order of transplants
reshape wide tplant_date, i(z_patid) j(order) // Creating one observation per patient

*Saving data
tempfile transplant_dates
save `transplant_dates'

***Getting hospitalization dates***

*Loading one line for each inpatient claim
clear
odbc load, exec("select * from HCCI_2.INP_SDDV2 is2 WHERE clmseq ='1' AND yr<2020;") dsn("Vertica") user("`username'") password("`password'")

*Cleaning hospitalization data
drop if over65_flag=="1" // Dropping if enrollee over age 65
destring admit_type, replace
collapse (min) fst_admtdt admit_type (max) lst_dischdt, by(z_patid yr mnth) // Getting admission and discharge date and admission type by patient-month

*Saving hospitalization data
tempfile hosp_month
save `hosp_month'

***Getting total spending by category***

*Getting monthly total of inpatient spending by patient-month
clear
odbc load, exec("select yr, mnth, z_patid, SUM(amt_net_paid) as ins_spend_ip, SUM(coins) as coins_ip, SUM(copay) as copay_ip, SUM(deduct) as deduct_ip FROM HCCI_2.INP_SDDV2 is2 WHERE yr<2020 GROUP BY z_patid, yr, mnth ORDER BY z_patid, yr, mnth;") dsn("Vertica") user("`username'") password("`password'")
tempfile ip_spend
save `ip_spend'

*Getting monthly total of outpatient spending by patient-month
clear
odbc load, exec("select yr, mnth, z_patid, SUM(amt_net_paid) as ins_spend_op, SUM(coins) as coins_op, SUM(copay) as copay_op, SUM(deduct) as deduct_op FROM HCCI_2.OP_SDDV2 os2 where yr<2020 GROUP BY z_patid, yr, mnth ORDER BY z_patid, yr, mnth;") dsn("Vertica") user("`username'") password("`password'")
tempfile op_spend
save `op_spend'

*Getting monthly total of physician services spending by patient-month
local dialysis_codes "proc_cd ='90935' OR proc_cd ='90937' OR proc_cd ='90945' OR proc_cd ='90947' OR proc_cd ='90999' OR proc_cd ='90989' OR proc_cd ='G0257' OR proc_cd ='99512' OR rvnu_cd ='0821' OR rvnu_cd ='0831' OR rvnu_cd ='0841' OR rvnu_cd ='0851' OR rvnu_cd ='0881' OR (proc_cd>='90951' AND proc_cd<='90970')" // Defining list of dialysis procedures
clear
odbc load, exec("select yr, mnth, z_patid, SUM(amt_net_paid) as ins_spend_phys, SUM(coins) as coins_phys, SUM(copay) as copay_phys, SUM(deduct) as deduct_phys FROM HCCI_2.PHYS_SDDV2 ps where yr<2020 AND z_patid IN (select z_patid FROM HCCI_2.OP_SDDV2 os WHERE `dialysis_codes') GROUP BY z_patid, yr, mnth ORDER BY z_patid, yr, mnth;") dsn("Vertica") user("`username'") password("`password'") // Loading data only for enrollees that ever have a dialysis claim
tempfile phys_spend_diallimit
save `phys_spend_diallimit'

*Getting monthly total of prescription drug spending by patient-month
clear
odbc load, exec("select yr, mnth, z_patid, SUM(amt_net_paid) as ins_spend_rx, SUM(copay_coins) as copay_rx, SUM(deduct) as deduct_rx FROM HCCI_2.RX_SDDV2 rs WHERE yr<2020 GROUP BY z_patid, yr, mnth ORDER BY z_patid, yr, mnth;") dsn("Vertica") user("`username'") password("`password'")
tempfile rx_spend
save `rx_spend'

***Getting enrollment data for dialysis patients***

*Loading enrollment data for dialysis patients
clear
odbc load, exec("select * FROM HCCI_2.MBR_SDDV2 ms where yr<2020 AND z_patid IN (select z_patid FROM HCCI_2.OP_SDDV2 os WHERE `dialysis_codes');") dsn("Vertica") user("`username'") password("`password'")
duplicates drop

*Making sure they have a unique zip-code
bysort z_patid yr mnth mbr_zip_5_cd: gen zipcount=_n==1
bysort z_patid yr mnth: egen zips=total(zipcount)
drop if zips>1 & mbr_zip_5_cd=="99999" | mbr_zip_5_cd=="9999"
replace mbr_zip_5_cd="" if zips>1
drop zipcount zips

*Making demographics missing if conflicting
foreach var in sex age_band_cd rel_cd mbr_state mbr_cbsa hrr_cd prod funding sic {
	bysort z_patid yr mnth `var': gen `var'count=_n==1
	bysort z_patid yr mnth: egen `var's=total(`var'count)
	replace `var'="" if `var's>1
	drop `var'count `var's
}

*Assuming coverage if conflicting and assuming not covered by ESI if conflicting
foreach var in rx_cvg_ind mh_cov_ind over65_flag esi_flag {
	bysort z_patid yr mnth `var': gen `var'count=_n==1
	bysort z_patid yr mnth: egen `var's=total(`var'count)
	replace `var'="1" if `var's>1
	if "`var'"=="esi_flag" {
		replace `var'="0" if `var's>1
	}
	drop `var'count `var's
}
duplicates drop // Dropping duplicate observations

*Saving data
tempfile enroll_diallimit
save `enroll_diallimit'

***Getting dialysis spending and identifying sample***

*Loading dialysis claims
clear
odbc load, exec("select * FROM HCCI_2.OP_SDDV2 os WHERE yr<2020 AND (`dialysis_codes');") dsn("Vertica") user("`username'") password("`password'")

*Cleaning data
drop if over65_flag=="1" // Dropping if enrollee is over age 65
gen date_start=mofd(fst_dt) // Getting first month on claim
gen date_end=mofd(lst_dt) // Getting last month on claim
bysort z_patid: egen dial_startdate=min(date_start) // Identifying first session
gen month_on_dial=date_end-dial_startdate // Making event time variable
destring primary_cov_ind, replace
collapse (sum) units tot_ins_spend=amt_net_paid tot_pat_spend=tot_mem_cs tot_deduct=deduct tot_spend=calc_allwd ///
		 (min) primary_cov_ind date_start ///
		 (max) month_on_dial, by(z_patid yr mnth) // Getting monthly dialysis spending totals by enrollee-month

*Saving data
tempfile dialysis_patmonth_spendevent
save `dialysis_patmonth_spendevent'

***Merging all data for dialysis patients***

*Getting list of dialysis patients
bysort z_patid: keep if _n==1 // Keeping one observation per dialysis patient
keep z_patid // Keeping only patient ID variable

*Saving data
tempfile dialysis_patients
save `dialysis_patients'

*Limiting monthly spending data to dialysis patients
foreach set in hosp_month ip_spend op_spend phys_spend_diallimit rx_spend {
	use `dialysis_patients', clear // Loading spending data
	merge 1:m z_patid using ``set''  // Merging with patient list
	keep if _merge==3 // Keeping only spending-patient matches
	drop _merge
	tempfile `set'_dial
	save ``set'_dial'
}

*Merging data on each spending category
use `dialysis_patmonth_spendevent', clear
foreach set in hosp_month ip_spend op_spend phys_spend_diallimit rx_spend {
	merge 1:1 z_patid yr mnth using ``set'_dial' // Merging with non-dialysis spending data
	if "`set'"=="hosp_month" {
		gen in_hosp=_merge!=1 // Generating indicator for being hospitalized
	}
	drop _merge
}

merge 1:1 z_patid yr mnth using `enroll_diallimit.dta' // Merging with enrollment data
gen enrolled=_merge!=1 // Creating an indicator for being enrolled
drop _merge // Droppig variable indicating merge success

rename tot_* *_dial // Renaming some variables

*Replacing missing spending values with 0
foreach var in in_hosp ins_spend_ip coins_ip copay_ip deduct_ip ins_spend_op coins_op copay_op deduct_op ins_spend_phys coins_phys copay_phys deduct_phys ins_spend_rx copay_rx deduct_rx {
	replace `var'=0 if missing(`var')
}

*Creating out-of-pocket spending variables
foreach type in phys op ip {
	gen pat_spend_`type'=copay_`type'+coins_`type'+deduct_`type' // Summing copayment, coinsurance, and deductible payments
}
gen pat_spend_rx=copay_rx+deduct_rx // Summing copayment and deductible payments

*Creating total spending variables
foreach var in pat_spend ins_spend deduct {
	gen total_`var'=`var'_phys+`var'_op+`var'_ip+`var'_rx // Summing physician services, outpatient, inpatient, and prescription drug spending
}
gen total_spending=total_pat_spend+total_ins_spend // Summing patient and insurance spending
foreach var in phys op ip rx {
	gen tot_spend_`var'=pat_spend_`var'+ins_spend_`var' // Summing patient and insurance spending
}

***Cleaning merged data***

*Cleaning things up
gen date="1-"+mnth+"-"+yr
gen t=mofd(date(date,"DMY"))
format t %tm
bysort z_patid: egen dial_start=min(date_start)
gen months_from_diag=t-dial_start

*Getting everything in 2019 terms
foreach var in spend_dial total_pat_spend total_spending tot_spend_op tot_spend_ip tot_spend_phys tot_spend_rx {
	replace `var'=`var'*1.0176 if yr=="2018"
	replace `var'=`var'*1.0430 if yr=="2017"
	replace `var'=`var'*1.0652 if yr=="2016"
	replace `var'=`var'*1.0786 if yr=="2015"
	replace `var'=`var'*1.0799 if yr=="2014"
	replace `var'=`var'*1.0974 if yr=="2013"
	replace `var'=`var'*1.1135 if yr=="2012"
}

*Keeping only patients in coordination period
sort z_patid t
by z_patid: gen months_enrolled=_n
gen dial_start_enrol=months_enrolled==1 & months_from_diag==0
by z_patid: egen dial_enroll=max(dial_start_enrol)
gen inrange=months_from_diag>=0 & months_from_diag<33 & dial_enroll!=1

*Creating indicator variables for covariates
gen male=1 if sex=="M"
replace male=0 if sex=="F"
gen female=1-male
gen minor=age_band_cd=="01"
gen age1824=age_band_cd=="02"
gen age2534=age_band_cd=="03"
gen age3544=age_band_cd=="04"
gen age4554=age_band_cd=="05"
gen age5564=age_band_cd=="06"
gen epo=prod=="EPO"
gen hmo=prod=="HMO"
gen ind=prod=="IND"
gen pos=prod=="POS"
gen ppo=prod=="PPO"
gen dependent=rel_cd=="DEP"
gen selffund=funding=="0"
destring rx_cvg_ind, replace
destring mh_cov_ind, replace

*Creating indicator for receiving dialysis treatment
gen treated=units>=1 & !missing(units)

*Creating non-dialysis outpatient spending variable
replace spend_dial=0 if missing(spend_dial)
gen spend_op_nodial=tot_spend_op-spend_dial

*Labeling variables
label var male "Male"
label var female "Female"
label var minor "\hspace*{0.5cm} under 18"
label var age1824 "\hspace*{0.5cm} 18-24"
label var age2534 "\hspace*{0.5cm} 25-34"
label var age3544 "\hspace*{0.5cm} 35-44"
label var age4554 "\hspace*{0.5cm} 45-54"
label var age5564 "\hspace*{0.5cm} 55-64"
label var ppo "\hspace*{0.5cm} PPO"
label var pos "\hspace*{0.5cm} POS"
label var hmo "\hspace*{0.5cm} HMO"
label var ind "\hspace*{0.5cm} Indemnity"
label var epo "\hspace*{0.5cm} EPO"
label var dependent "Dependent"
label var selffund "Self-Funded"
label var rx_cvg_ind "Pharmacy Benefit"
label var mh_cov_ind "Mental Health Coverage"

label var months_enrolled "Months Enrolled"
label var months_from_diag "Months Since First Treatment"
label var treated "Receives Dialysis"
label var in_hosp "Hospitalized"

label var total_pat_spend "Out-of-Pocket Spending"
label var total_spending "Total Spending"

label var spend_dial "\hspace*{0.5cm} Dialysis"
label var spend_op_nodial "\hspace*{0.5cm} Other Outpatient Care"
label var tot_spend_ip "\hspace*{0.5cm} Inpatient Care"
label var tot_spend_phys  "\hspace*{0.5cm} Physician Services"
label var tot_spend_rx "\hspace*{0.5cm} Prescription Medication"

*Saving data
tempfile mergedata_withmissing
save `mergedata_withmissing'

*Dropping patients with missing variables
gen dropme=missing(sex) | missing(age_band_cd) | missing(prod) | prod=="UNK" | missing(rel_cd) | missing(funding) | missing(rx_cvg_ind) | missing(mh_cov_ind)
tab dropme
drop if dropme==1
drop dropme

*Keeping balanced panel of patients
bysort z_patid: egen min_since=min(months_from_diag)
bysort z_patid: egen max_since=max(months_from_diag)
gen stable_range=min_since<=-12 & max_since>=12
gen est_range=months_from_diag>=-12 & months_from_diag<=12
bysort z_patid stable_range est_range: gen months=_N
gen est_sample=months==25 & stable_range==1 & est_range==1

*Getting statistics on attrition
preserve
gen pre_range=months_from_diag>=-12 & months_from_diag<=-1
bysort z_patid pre_range: gen pre_months=_N if pre_range==1
gen full_pre=pre_months==12
bysort z_patid: egen keep_pre=max(full_pre)
keep if months_from_diag>=-12 & months_from_diag<=12 & keep_pre==1
tab months_from_diag
restore

keep if est_sample==1

*Getting RX spending for those with continuous coverage
bysort z_patid rx_cvg_ind: gen months_with_rx_cov=_N if rx_cvg_ind==1
gen rxspend=tot_spend_rx if months_with_rx_cov==25
label var rxspend "RX Spending with Coverage"

*Winsorizing
foreach var in total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend {
	if "`var'"!="rxspend" {
		replace `var'=0 if missing(`var')
	}
	su `var', d
	replace `var'=`r(p99)' if `var'>`r(p99)' & !missing(`var')
}

gen post=months_from_diag>=0

******************************
*Reporting Summary Statistics*
******************************

*Table 1
estimates clear
eststo: estpost tabstat male female minor age1824 age2534 age3544 age4554 age5564 ppo pos hmo ind epo dependent selffund rx_cvg_ind mh_cov_ind months_enrolled months_from_diag treated in_hosp total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend if post==0, statistics(mean sd n) col(stat)
eststo: estpost tabstat male female minor age1824 age2534 age3544 age4554 age5564 ppo pos hmo ind epo dependent selffund rx_cvg_ind mh_cov_ind months_enrolled months_from_diag treated in_hosp total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend if post==1, statistics(mean sd n) col(stat)
esttab using "${outpath}totalspending_sumstats_estsamp.tex", cells("mean(fmt(%5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.1fc  %5.1fc %5.3fc %5.3fc %12.2fc) label(Mean)) sd(fmt(%12.2fc) label(SD))") label nonum booktabs frag refcat(minor "Age" ppo "Plan Type" spend_dial "Amount Spent on\ldots", nolabel) stats(N, label("Patient-Months") fmt(%16.0fc)) nomti replace

*Getting confidence intervals to report in text
ci means male age5564 months_enrolled if post==0

***Getting summary statistics without dropping those with missing variables***

preserve
use `mergedata_withmissing', clear // Loading data including observations with missing data

*Redoing sample restrictions keeping observations with missing data
bysort z_patid: egen min_since=min(months_from_diag)
bysort z_patid: egen max_since=max(months_from_diag)
gen stable_range=min_since<=-12 & max_since>=12
gen est_range=months_from_diag>=-12 & months_from_diag<=12
bysort z_patid stable_range est_range: gen months=_N
gen est_sample=months==25 & stable_range==1 & est_range==1
keep if est_sample==1
bysort z_patid rx_cvg_ind: gen months_with_rx_cov=_N if rx_cvg_ind==1
gen rxspend=tot_spend_rx if months_with_rx_cov==25
label var rxspend "RX Spending with Coverage"
foreach var in total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend {
	if "`var'"!="rxspend" {
		replace `var'=0 if missing(`var')
	}
	su `var', d
	replace `var'=`r(p99)' if `var'>`r(p99)' & !missing(`var')
}
gen post=months_from_diag>=0

*eTable
estimates clear
eststo: estpost tabstat male female minor age1824 age2534 age3544 age4554 age5564 ppo pos hmo ind epo dependent selffund rx_cvg_ind mh_cov_ind months_enrolled months_from_diag treated in_hosp total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend if post==0, statistics(mean sd n) col(stat)
eststo: estpost tabstat male female minor age1824 age2534 age3544 age4554 age5564 ppo pos hmo ind epo dependent selffund rx_cvg_ind mh_cov_ind months_enrolled months_from_diag treated in_hosp total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys tot_spend_rx rxspend if post==1, statistics(mean sd n) col(stat)
esttab using "${outpath}totalspending_sumstats_keepmissing.tex", cells("mean(fmt(%5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.3fc %5.1fc  %5.1fc %5.3fc %5.3fc %12.2fc) label(Mean)) sd(fmt(%12.2fc) label(SD))") label nonum booktabs frag refcat(minor "Age" ppo "Plan Type" spend_dial "Amount Spent on\ldots", nolabel) stats(N, label("Patient-Months") fmt(%16.0fc)) nomti replace
restore

***Conducting event study analysis***

*Making independent variable for event study
gen months_since=months_from_diag+100

*Estimating event studies (Figure 1)
estimates clear
foreach var in total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys rxspend {
	eststo: reghdfe `var' ib88.months_since, a(age_band_cd sex rel_cd funding prod) vce(cluster z_patid)
}
esttab * using "${outpath}event_studies.csv", replace keep(*months_since) se nostar noparen wide csv stat(r2 N)

*Getting baselines for Figure 1
ci means total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys rxspend if months_since==88

***Getting change in dialysis spending for transplant patients***

*Merging transplant data
merge m:1 z_patid using `transplant_dates'
drop if _merge==2
drop _merge

*Identifying transplant patients
gen tplant=0
forvalues i=1/21 {
	replace tplant=1 if t==tplant_date`i' // Creating indicator for getting a transplant in that month
}
bysort z_patid: egen any_tplant=max(tplant) // Creating indicator for getting a transplant within analysis window
tab any_tplant if months_from_diag==0 // Getting share that get a transplant

*Estimating event studies for those without transplants
reghdfe spend_dial ib88.months_since if any_tplant==0, a(age_band_cd sex rel_cd funding prod) vce(cluster z_patid)

***Estimating pre-post changes in spending***

*Getting pre- and post-initiation means (Table 2)
ci means total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys rxspend if post==0
ci means total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_ip tot_spend_phys rxspend if post==1

*Getting unadjusted differences (Table 2)
estimates clear
foreach var in total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_phys tot_spend_ip rxspend {
	eststo: reg `var' post, cluster(z_patid)
	estadd ysumm
}

*Labeling variables
label var post "After First Treatment"
label var spend_dial "Dialysis"
label var spend_op_nodial "Non-Dial. OP"
label var tot_spend_phys "Physician Services"
label var tot_spend_ip "Inpatient"
label var tot_spend_rx "Prescription Drugs"
label var total_pat_spend "OOP"
label var total_spending "Total"

esttab using "${outpath}unadjusted_diff.tex", ///
	keep(post) lab se booktabs frag replace ///
	cells("b(fmt(%12.2fc))" "se(fmt(%12.2fc))") ///
	stats(ymean r2 N, label("Dep. Var. Mean" "R^2" "Observations"))

*Getting adjusted differences (Table 2)
estimates clear
foreach var in total_spending total_pat_spend spend_dial spend_op_nodial tot_spend_phys tot_spend_ip rxspend {
	eststo: reghdfe `var' post, a(z_patid age_band_cd sex rel_cd funding prod) vce(cluster z_patid)
	estadd ysumm
}
esttab using "${outpath}adjusted_diff.tex", ///
	keep(post) lab se booktabs frag replace ///
	cells("b(fmt(%12.2fc))" "se(fmt(%12.2fc))") ///
	stats(ymean r2 N, label("Dep. Var. Mean" "R^2" "Observations"))
	
*Getting share that are hospitalized at start of dialysis
gen crash_hosp=in_hosp if months_from_diag==-1 | months_from_diag==0
bysort z_patid: egen crash=max(crash_hosp)
ci prop crash if months_from_diag==0

*Getting total spending in 12 months before and 12 months after
drop if months_since==112
collapse (sum) total_spending, by(post z_patid)

***Making histogram of total spending (Figure 2)***

preserve
gen histbin=floor(total_spending/20000) // Setting bin width
collapse (count) patients=total_spending, by(histbin post) // Getting patients in each bin
drop if missing(histbin)
su histbin if post==0 & patients<10 // Getting lowest level of spending with fewer than 10 enrollees
replace histbin=r(min) if post==0 & histbin>r(min) // Winsorizing in accordance with DUA
su histbin if post==1 & patients<10 // Getting lowest level of spending with fewer than 10 enrollees
replace histbin=r(min) if post==1 & histbin>r(min) // Winsorizing in accordance with DUA
collapse (sum) patients, by(histbin post) // Getting patient count in "or more" bin
gen spending=histbin*20000 // Assigning spending level to each bin
export excel using "${outpath}histogram.xlsx", firstrow(variables) replace // Exporting data
restore

***Getting statistics on total spending distribution***

*Getting percentiles to report in text
ci means total_spending if post==1
centile total_spending if post==1, centile(80 90 99)

set seed 8675309 // Setting random number seed (Hi Jenny)

*Defining function to bootstrap confidence intervals on change in median
program define pct_diff50, rclass
	_pctile total_spending if post==1, p(50) // Getting post-dialysis median
	local post=`r(r1)'
	_pctile total_spending if post==0, p(50) // Gettin pre-dialysis median
	local pre=`r(r1)'
	return scalar diff=`post'-`pre' // Getting difference
end
bootstrap r(diff), reps(200): pct_diff50 // Bootstrapping the difference 200 times

*Defining function to bootstrap confidence intervals on change in 90th percentile
program define pct_diff90, rclass
	_pctile total_spending if post==1, p(90) // Getting post-dialysis 90th percentile
	local post=`r(r1)'
	_pctile total_spending if post==0, p(90) // Getting pre-dialysis 90th percentile
	local pre=`r(r1)'
	return scalar diff=`post'-`pre' // Getting difference
end
bootstrap r(diff), reps(200): pct_diff90 // Bootstrapping the difference 200 times

*Defining function to bootstrap confidence intervals on change in 99th percentile
program define pct_diff99, rclass
	_pctile total_spending if post==1, p(99) // Getting post-dialysis 99th percentile
	local post=`r(r1)'
	_pctile total_spending if post==0, p(99) // Getting pre-dialysis 99th percentile
	local pre=`r(r1)'
	return scalar diff=`post'-`pre' // Getting difference
end
bootstrap r(diff), reps(200): pct_diff99 // Bootstrapping the difference 200 times

*Shutting things down
cap log close
exit, clear